@@ -9,6 +9,7 @@ import lib.bt as bt
 import lib.util as util
 import lib.archive as archive
 import lib.img as img
+import lib.plb as plb
 
 
 main_app = typer.Typer()
@@ -18,6 +19,7 @@ main_app.add_typer(bt.bt_app,           name="bt"     )
 main_app.add_typer(util.util_app,       name="util"   )
 main_app.add_typer(archive.archive_app, name="archive")
 main_app.add_typer(img.img_app,         name="img"    )
+main_app.add_typer(plb.plb_app,         name="plb"    )
 
 
 if __name__ == "__main__":
